==> open-xchange-mobile-api-facade_1.0.3.orig.tar.bz2: open-xchange-mobile-api-facade-1.0.3/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/weakforce/models/serializers/LTAttrsDeserializer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.weakforce.models.serializers;

import java.io.IOException;
import java.util.Iterator;
import java.util.Map.Entry;

import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonDeserializer;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.node.BooleanNode;
import com.fasterxml.jackson.databind.node.DoubleNode;
import com.fasterxml.jackson.databind.node.IntNode;
import com.fasterxml.jackson.databind.node.TextNode;
import com.openexchange.mobile.api.facade.weakforce.models.LTAttrs;

public class LTAttrsDeserializer extends JsonDeserializer<LTAttrs> {

    @Override
    public LTAttrs deserialize(JsonParser parser, DeserializationContext context) throws IOException, JsonProcessingException {
        LTAttrs attributes = new LTAttrs();
        JsonNode node = parser.getCodec().readTree(parser);
        Iterator<Entry<String, JsonNode>> it = node.fields();
        while (it.hasNext()) {
            Entry<String, JsonNode> attribute = it.next();
            String name = attribute.getKey();
            JsonNode valueNode = attribute.getValue();
            Object value;
            if (valueNode instanceof TextNode) {
                value = ((TextNode) valueNode).asText();
            } else if (valueNode instanceof BooleanNode) {
                value = ((BooleanNode) valueNode).asBoolean();
            } else if (valueNode instanceof IntNode) {
                value = ((IntNode) valueNode).asInt();
            } else if (valueNode instanceof DoubleNode) {
                value = ((DoubleNode) valueNode).asDouble();
            } else {
                value = valueNode.toString();
            }
            attributes.add(name, value);
        }
        return attributes;
    }

}

==> open-xchange-mobile-api-facade_1.4.16.orig.tar.bz2: open-xchange-mobile-api-facade-1.4.16/com.openexchange.mobile.api.facade/src/com/openexchange/mobile/api/facade/weakforce/models/serializers/LTAttrsDeserializer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.mobile.api.facade.weakforce.models.serializers;

import java.io.IOException;
import java.util.Iterator;
import java.util.Map.Entry;

import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonDeserializer;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.node.BooleanNode;
import com.fasterxml.jackson.databind.node.DoubleNode;
import com.fasterxml.jackson.databind.node.IntNode;
import com.fasterxml.jackson.databind.node.TextNode;
import com.openexchange.mobile.api.facade.weakforce.models.LTAttrs;

public class LTAttrsDeserializer extends JsonDeserializer<LTAttrs> {

    @Override
    public LTAttrs deserialize(JsonParser parser, DeserializationContext context) throws IOException, JsonProcessingException {
        LTAttrs attributes = new LTAttrs();
        JsonNode node = parser.getCodec().readTree(parser);
        if (node == null) {
            throw new JsonParseException(parser, "Could not deserialize LTAttrs object");
        }
        Iterator<Entry<String, JsonNode>> it = node.fields();
        while (it.hasNext()) {
            Entry<String, JsonNode> attribute = it.next();
            String name = attribute.getKey();
            JsonNode valueNode = attribute.getValue();
            Object value;
            if (valueNode instanceof TextNode) {
                value = ((TextNode) valueNode).asText();
            } else if (valueNode instanceof BooleanNode) {
                value = ((BooleanNode) valueNode).asBoolean();
            } else if (valueNode instanceof IntNode) {
                value = ((IntNode) valueNode).asInt();
            } else if (valueNode instanceof DoubleNode) {
                value = ((DoubleNode) valueNode).asDouble();
            } else {
                value = valueNode.toString();
            }
            attributes.add(name, value);
        }
        return attributes;
    }

}
